@@ -9,4 +9,6 @@ from .clean import *  # noqa: F403
 from .qcfilter import *  # noqa: F403
 from .qctests import *  # noqa: F403
 from .radiometer_tests import *  # noqa: F403
+from .bsrn_tests import *  # noqa: F403
+from .comparison_tests import *  # noqa: F403
 from .sp2 import SP2ParticleCriteria, get_waveform_statistics
